@@ -2,27 +2,27 @@ context("plot.trajectory")
 
 test_graph <- function(x, name, from, to) {
   expect_true(inherits(plot(x), "htmlwidget"))
-  graph <- trajectory_graph(x)
+  graph <- trajectory_graph(x, scales::brewer_pal("qual"))
   expect_true(inherits(graph, "dgr_graph"))
   dot <- DiagrammeR::generate_dot(graph)
   expect_true(inherits(dot, "character"))
   expect_true(length(dot) == 1)
-  graph_lines <- strsplit(dot, "\n")[[1]]
+  graph_lines <- utils::capture.output(cat(dot))
 
   nodes <- graph_lines[grep("label", graph_lines)]
   id <- nodes %>%
-    sub("[[:space:]]*'", "", .) %>%
-    sub("' \\[.*", "", .) %>%
+    sub("[[:space:]]*'*\"*", "", .) %>%
+    sub("'*\"* \\[.*", "", .) %>%
     as.numeric()
   label <- nodes %>%
-    sub(".*label = '", "", .) %>%
-    sub("'.*", "", .)
+    sub(".*label = '*\"*", "", .) %>%
+    sub("'*\"*,.*", "", .)
   nodes <- data.frame(id=id, label=label) %>%
     dplyr::arrange_("id")
 
   edges <- graph_lines[grep("->", graph_lines)] %>%
     sub(" \\[.*", "", .) %>%
-    gsub("'", "", .) %>%
+    gsub("'*\"*", "", .) %>%
     strsplit("->") %>%
     lapply(as.numeric) %>%
     as.data.frame %>% t %>%
@@ -56,8 +56,8 @@ test_that("a single-node trajectory is correctly converted to graph", {
 
 test_that("a simple trajectory is correctly converted to graph", {
   x <- trajectory() %>%
-    seize("resource", 1) %>%
-    release("resource", 1)
+    seize("res", 1) %>%
+    release("res", 1)
 
   test_graph(x, c("Seize", "Release"), 1, 2)
 })
@@ -72,16 +72,14 @@ test_that("a rollback with variable amount is correctly converted to graph", {
 
 test_that("a complex trajectory is correctly converted to graph", {
   x <- trajectory() %>%
-    seize("resource", 1) %>%
-    timeout(function() rnorm(1, 15)) %>%
-    release("resource", 1) %>%
+    seize("res0", 1) %>%
     branch(function() 1, c(TRUE, FALSE),
            trajectory() %>%
              clone(2,
                    trajectory() %>%
-                     seize("resource", 1) %>%
+                     seize("res1", 1) %>%
                      timeout(1) %>%
-                     release("resource", 1),
+                     release("res1", 1),
                    trajectory() %>%
                      trap("signal",
                           handler=trajectory() %>%
@@ -89,18 +87,19 @@ test_that("a complex trajectory is correctly converted to graph", {
                      timeout(1)),
            trajectory() %>%
              set_attribute("dummy", 1) %>%
-             set_attribute("dummy", function() 1) %>%
-             seize("resource", function() 1) %>%
+             seize("res2", function() 1) %>%
              timeout(function() rnorm(1, 20)) %>%
-             release("resource", function() 1) %>%
-             rollback(9)) %>%
-    timeout(1) %>%
-    rollback(2)
+             release("res2", function() 1) %>%
+             release("res0", 1) %>%
+             rollback(11)) %>%
+    synchronize() %>%
+    rollback(2) %>%
+    release("res0", 1)
 
   test_graph(x,
-             c("Seize", "Timeout", "Release", "Branch", "Clone", "Seize", "Timeout",
-               "Release", "Trap", "Timeout", "Timeout", "SetAttribute", "SetAttribute",
-               "Seize", "Timeout", "Release", "Rollback", "Timeout", "Rollback"),
-             c(1, 2, 3, 4, 4, 4, 5, 5, 5, 6, 7, 8, 9, 9, 11, 12, 13, 14, 15, 16, 17, 18, 19),
-             c(2, 3, 4, 5, 12, 18, 6, 9, 18, 7, 8, 18, 10, 11, 18, 13, 14, 15, 16, 17, 1, 19, 4))
+             c("Seize", "Branch", "Clone", "Seize", "Timeout", "Release", "Trap",
+               "Timeout", "Timeout", "SetAttribute", "Seize", "Timeout", "Release",
+               "Release", "Rollback", "Synchronize", "Rollback", "Release"),
+             c(1, 2, 2, 2, 3, 3, 3, 4, 5, 6, 7, 7, 9, 10, 11, 12, 13, 14, 15, 16, 17, 17),
+             c(2, 3, 10, 16, 4, 7, 16, 5, 6, 16, 8, 9, 16, 11, 12, 13, 14, 15, 1, 17, 2, 18))
 })
